pub struct WaitGroupHandle { /* private fields */ }Expand description
A handle to a wait group that allows adding new wait guards.
Implementations
Sourceimpl WaitGroupHandle
impl WaitGroupHandle
Sourcepub fn never() -> Self
pub fn never() -> Self
Create a new wait group handle that is not associated with any wait group.
Sourcepub fn is_waiting(&self) -> bool
pub fn is_waiting(&self) -> bool
Return whether the wait group is currently waiting.